Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Url string
Key string
// Debug is an optional writer which will be used for debug output.
Debug io.Writer
}
Config is the configuration struct you should pass to New().
type Translation ¶
type Translation struct {
Config
// contains filtered or unexported fields
}
Click to show internal directories.
Click to hide internal directories.